Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb,
sig/client.rbs
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a :region and :credentials.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateCentralizationRuleForOrganizationResponseSuccess, _CreateS3TableIntegrationResponseSuccess, _CreateTelemetryPipelineResponseSuccess, _CreateTelemetryRuleForOrganizationResponseSuccess, _CreateTelemetryRuleResponseSuccess, _DeleteTelemetryPipelineResponseSuccess, _GetCentralizationRuleForOrganizationResponseSuccess, _GetS3TableIntegrationResponseSuccess, _GetTelemetryEnrichmentStatusResponseSuccess, _GetTelemetryEvaluationStatusForOrganizationResponseSuccess, _GetTelemetryEvaluationStatusResponseSuccess, _GetTelemetryPipelineResponseSuccess, _GetTelemetryRuleForOrganizationResponseSuccess, _GetTelemetryRuleResponseSuccess, _ListCentralizationRulesForOrganizationResponseSuccess, _ListResourceTelemetryForOrganizationResponseSuccess, _ListResourceTelemetryResponseSuccess, _ListS3TableIntegrationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTelemetryPipelinesResponseSuccess, _ListTelemetryRulesForOrganizationResponseSuccess, _ListTelemetryRulesResponseSuccess, _StartTelemetryEnrichmentResponseSuccess, _StopTelemetryEnrichmentResponseSuccess, _TestTelemetryPipelineResponseSuccess, _UpdateCentralizationRuleForOrganizationResponseSuccess, _UpdateTelemetryPipelineResponseSuccess, _UpdateTelemetryRuleForOrganizationResponseSuccess, _UpdateTelemetryRuleResponseSuccess, _ValidateTelemetryPipelineConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization.
-
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics.
-
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data.
-
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account.
-
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization.
-
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule.
-
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data.
-
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources.
-
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account.
-
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule.
-
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule.
-
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
-
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
-
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
-
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule.
-
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
-
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource.
-
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account.
-
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account.
-
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization.
-
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource.
-
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization.
-
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
-
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
-
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization.
-
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2643 2644 2645 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2643 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2646 2647 2648 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2646 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2616 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.33.0' Seahorse::Client::Request.new(handlers, context) end |
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
86 |
# File 'sig/client.rbs', line 86
def create_centralization_rule_for_organization: (
|
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics. This integration enables querying CloudWatch telemetry data using analytics engines like Amazon Athena, Amazon Redshift, and Apache Spark.
98 |
# File 'sig/client.rbs', line 98
def create_s3_table_integration: (
|
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
113 |
# File 'sig/client.rbs', line 113
def create_telemetry_pipeline: (
|
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
127 |
# File 'sig/client.rbs', line 127
def create_telemetry_rule: (
|
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
139 |
# File 'sig/client.rbs', line 139
def create_telemetry_rule_for_organization: (
|
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule. This operation can only be called by the organization's management account or a delegated administrator account.
147 |
# File 'sig/client.rbs', line 147
def delete_centralization_rule_for_organization: (
|
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data. This operation removes the connection between CloudWatch Observability Admin and S3 Tables.
153 |
# File 'sig/client.rbs', line 153
def delete_s3_table_integration: (
|
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources. This operation stops data processing and removes the pipeline configuration.
162 |
# File 'sig/client.rbs', line 162
def delete_telemetry_pipeline: (
|
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
168 |
# File 'sig/client.rbs', line 168
def delete_telemetry_rule: (
|
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule. This operation can only be called by the organization's management account or a delegated administrator account.
174 |
# File 'sig/client.rbs', line 174
def delete_telemetry_rule_for_organization: (
|
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule. This operation can only be called by the organization's management account or a delegated administrator account.
192 |
# File 'sig/client.rbs', line 192
def get_centralization_rule_for_organization: (
|
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
207 |
# File 'sig/client.rbs', line 207
def get_s3_table_integration: (
|
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
218 219 |
# File 'sig/client.rbs', line 218
def get_telemetry_enrichment_status: () -> _GetTelemetryEnrichmentStatusResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetTelemetryEnrichmentStatusResponseSuccess
|
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
229 230 |
# File 'sig/client.rbs', line 229
def get_telemetry_evaluation_status: () -> _GetTelemetryEvaluationStatusResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetTelemetryEvaluationStatusResponseSuccess
|
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
240 241 |
# File 'sig/client.rbs', line 240
def get_telemetry_evaluation_status_for_organization: () -> _GetTelemetryEvaluationStatusForOrganizationResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetTelemetryEvaluationStatusForOrganizationResponseSuccess
|
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
248 |
# File 'sig/client.rbs', line 248
def get_telemetry_pipeline: (
|
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
265 |
# File 'sig/client.rbs', line 265
def get_telemetry_rule: (
|
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization's management account or a delegated administrator account.
282 |
# File 'sig/client.rbs', line 282
def get_telemetry_rule_for_organization: (
|
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization. This operation can only be called by the organization's management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
293 |
# File 'sig/client.rbs', line 293
def list_centralization_rules_for_organization: (
|
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see Auditing CloudWatch telemetry configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
307 |
# File 'sig/client.rbs', line 307
def list_resource_telemetry: (
|
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
323 |
# File 'sig/client.rbs', line 323
def list_resource_telemetry_for_organization: (
|
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
340 |
# File 'sig/client.rbs', line 340
def list_s3_table_integrations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource. Supports telemetry rule resources and telemetry pipeline resources.
351 |
# File 'sig/client.rbs', line 351
def list_tags_for_resource: (
|
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account. Returns up to
100 results. If more than 100 telemetry pipelines exist, include the
NextToken value from the response to retrieve the next set of
results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
362 |
# File 'sig/client.rbs', line 362
def list_telemetry_pipelines: (
|
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
374 |
# File 'sig/client.rbs', line 374
def list_telemetry_rules: (
|
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization. This operation can only be called by the organization's management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
387 |
# File 'sig/client.rbs', line 387
def list_telemetry_rules_for_organization: (
|
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
402 403 |
# File 'sig/client.rbs', line 402
def start_telemetry_enrichment: () -> _StartTelemetryEnrichmentResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _StartTelemetryEnrichmentResponseSuccess
|
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
406 |
# File 'sig/client.rbs', line 406
def start_telemetry_evaluation: (
|
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
413 |
# File 'sig/client.rbs', line 413
def start_telemetry_evaluation_for_organization: (
|
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
424 425 |
# File 'sig/client.rbs', line 424
def stop_telemetry_enrichment: () -> _StopTelemetryEnrichmentResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _StopTelemetryEnrichmentResponseSuccess
|
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
428 429 |
# File 'sig/client.rbs', line 428
def stop_telemetry_evaluation: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
432 433 |
# File 'sig/client.rbs', line 432
def stop_telemetry_evaluation_for_organization: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource. Supports telemetry rule resources and telemetry pipeline resources.
436 |
# File 'sig/client.rbs', line 436
def tag_resource: (
|
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment. This operation helps ensure your pipeline configuration works as expected.
447 |
# File 'sig/client.rbs', line 447
def test_telemetry_pipeline: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.
462 |
# File 'sig/client.rbs', line 462
def untag_resource: (
|
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
473 |
# File 'sig/client.rbs', line 473
def update_centralization_rule_for_organization: (
|
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
-
Pipeline name - The pipeline name is immutable
-
Pipeline ARN - The ARN is automatically generated and cannot be changed
-
Source type - Once a pipeline is created with a specific source type (such as S3, CloudWatch Logs, GitHub, or third-party sources), it cannot be changed to a different source type
Processors can be added, removed, or modified. However, some processors are not supported for third-party pipelines and cannot be added through updates.
Source-Specific Update Rules
CloudWatch Logs Sources (Vended and Custom)
: Updatable: sts_role_arn
**Fixed:** `data_source_name`, `data_source_type`, sink (must remain
`@original`)
S3 Sources (Crowdstrike, Zscaler, SentinelOne, Custom)
: Updatable: All SQS configuration parameters, sts_role_arn,
codec settings, compression type, bucket ownership settings, sink
log group
**Fixed:** `notification_type`, `aws.region`
GitHub Audit Logs
: Updatable: All Amazon Web Services Secrets Manager attributes,
scope (can switch between ORGANIZATION/ENTERPRISE), organization
or enterprise name, range, authentication credentials (PAT or
GitHub App)
Microsoft Sources (Entra ID, Office365, Windows)
: Updatable: All Amazon Web Services Secrets Manager attributes,
tenant_id, workspace_id (Windows only), OAuth2 credentials
(client_id, client_secret)
Okta Sources (SSO, Auth0)
: Updatable: All Amazon Web Services Secrets Manager attributes,
domain, range, OAuth2 credentials (client_id, client_secret)
Palo Alto Networks
: Updatable: All Amazon Web Services Secrets Manager attributes,
hostname, basic authentication credentials (username,
password)
ServiceNow CMDB
: Updatable: All Amazon Web Services Secrets Manager attributes,
instance_url, range, OAuth2 credentials (client_id,
client_secret)
Wiz CNAPP
: Updatable: All Amazon Web Services Secrets Manager attributes,
region, range, OAuth2 credentials (client_id, client_secret)
483 |
# File 'sig/client.rbs', line 483
def update_telemetry_pipeline: (
|
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.
496 |
# File 'sig/client.rbs', line 496
def update_telemetry_rule: (
|
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization's management account or a delegated administrator account.
507 |
# File 'sig/client.rbs', line 507
def update_telemetry_rule_for_organization: (
|
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline. This operation checks the configuration for syntax errors and compatibility issues.
518 |
# File 'sig/client.rbs', line 518
def validate_telemetry_pipeline_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2636 2637 2638 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2636 def waiter_names [] end |