Class: Aws::ObservabilityAdmin::Types::AccessDeniedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Indicates you don’t have permissions to perform the requested operation. The user or role that is making the request must have at least one IAM permissions policy attached that grants the required permissions. For more information, see [Access management for Amazon Web Services resources] in the IAM user guide.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amzn_error_typeString

The name of the exception.

Returns:

  • (String)


32
33
34
35
36
37
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 32

class AccessDeniedException < Struct.new(
  :message,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:

  • (String)


32
33
34
35
36
37
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 32

class AccessDeniedException < Struct.new(
  :message,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end