Class: Aws::ObservabilityAdmin::Types::ConfigurationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::ConfigurationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Provides a summary of pipeline configuration components including sources, processors, and destinations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_sources ⇒ Array<Types::DataSource>
The list of data sources that provide telemetry data to the pipeline.
-
#processor_count ⇒ Integer
The total number of processors configured in the pipeline.
-
#processors ⇒ Array<String>
The list of processors configured in the pipeline for data transformation.
-
#sinks ⇒ Array<String>
The list of destinations where processed data is sent.
-
#sources ⇒ Array<Types::Source>
The list of data sources configured in the pipeline.
Instance Attribute Details
#data_sources ⇒ Array<Types::DataSource>
The list of data sources that provide telemetry data to the pipeline.
341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 341 class ConfigurationSummary < Struct.new( :sources, :data_sources, :processors, :processor_count, :sinks) SENSITIVE = [] include Aws::Structure end |
#processor_count ⇒ Integer
The total number of processors configured in the pipeline.
341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 341 class ConfigurationSummary < Struct.new( :sources, :data_sources, :processors, :processor_count, :sinks) SENSITIVE = [] include Aws::Structure end |
#processors ⇒ Array<String>
The list of processors configured in the pipeline for data transformation.
341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 341 class ConfigurationSummary < Struct.new( :sources, :data_sources, :processors, :processor_count, :sinks) SENSITIVE = [] include Aws::Structure end |
#sinks ⇒ Array<String>
The list of destinations where processed data is sent.
341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 341 class ConfigurationSummary < Struct.new( :sources, :data_sources, :processors, :processor_count, :sinks) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::Source>
The list of data sources configured in the pipeline.
341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 341 class ConfigurationSummary < Struct.new( :sources, :data_sources, :processors, :processor_count, :sinks) SENSITIVE = [] include Aws::Structure end |