Class: Aws::ObservabilityAdmin::Types::CreateTelemetryPipelineInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::TelemetryPipelineConfiguration

The configuration that defines how the telemetry pipeline processes data, including sources, processors, and destinations. For more information about pipeline components, see the Amazon CloudWatch User Guide



491
492
493
494
495
496
497
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 491

class CreateTelemetryPipelineInput < Struct.new(
  :name,
  :configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the telemetry pipeline to create. The name must be unique within your account.

Returns:

  • (String)


491
492
493
494
495
496
497
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 491

class CreateTelemetryPipelineInput < Struct.new(
  :name,
  :configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The key-value pairs to associate with the telemetry pipeline resource for categorization and management purposes.

Returns:

  • (Hash<String,String>)


491
492
493
494
495
496
497
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 491

class CreateTelemetryPipelineInput < Struct.new(
  :name,
  :configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end