Class: Aws::ObservabilityAdmin::Types::CreateTelemetryRuleForOrganizationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::CreateTelemetryRuleForOrganizationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rule ⇒ Types::TelemetryRule
The configuration details for the organization-wide telemetry rule, including the resource type, telemetry type, destination configuration, and selection criteria for which resources the rule applies to across the organization.
-
#rule_name ⇒ String
A unique name for the organization-wide telemetry rule being created.
-
#tags ⇒ Hash<String,String>
The key-value pairs to associate with the organization telemetry rule resource for categorization and management purposes.
Instance Attribute Details
#rule ⇒ Types::TelemetryRule
The configuration details for the organization-wide telemetry rule, including the resource type, telemetry type, destination configuration, and selection criteria for which resources the rule applies to across the organization.
516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 516 class CreateTelemetryRuleForOrganizationInput < Struct.new( :rule_name, :rule, :tags) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
A unique name for the organization-wide telemetry rule being created.
516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 516 class CreateTelemetryRuleForOrganizationInput < Struct.new( :rule_name, :rule, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The key-value pairs to associate with the organization telemetry rule resource for categorization and management purposes.
516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 516 class CreateTelemetryRuleForOrganizationInput < Struct.new( :rule_name, :rule, :tags) SENSITIVE = [] include Aws::Structure end |