Class: Aws::ObservabilityAdmin::Types::CreateTelemetryRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ruleTypes::TelemetryRule

The configuration details for the telemetry rule, including the resource type, telemetry type, destination configuration, and selection criteria for which resources the rule applies to.



554
555
556
557
558
559
560
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 554

class CreateTelemetryRuleInput < Struct.new(
  :rule_name,
  :rule,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_nameString

A unique name for the telemetry rule being created.

Returns:

  • (String)


554
555
556
557
558
559
560
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 554

class CreateTelemetryRuleInput < Struct.new(
  :rule_name,
  :rule,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The key-value pairs to associate with the telemetry rule resource for categorization and management purposes.

Returns:

  • (Hash<String,String>)


554
555
556
557
558
559
560
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 554

class CreateTelemetryRuleInput < Struct.new(
  :rule_name,
  :rule,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end