Class: Aws::ObservabilityAdmin::Types::GetCentralizationRuleForOrganizationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::GetCentralizationRuleForOrganizationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#centralization_rule ⇒ Types::CentralizationRule
The configuration details for the organization centralization rule.
-
#created_region ⇒ String
The Amazon Web Services region where the organization centralization rule was created.
-
#created_time_stamp ⇒ Integer
The timestamp when the organization centralization rule was created.
-
#creator_account_id ⇒ String
The Amazon Web Services Account that created the organization centralization rule.
-
#failure_reason ⇒ String
The reason why an organization centralization rule is marked UNHEALTHY.
-
#last_update_time_stamp ⇒ Integer
The timestamp when the organization centralization rule was last updated.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the organization centralization rule.
-
#rule_health ⇒ String
The health status of the organization centralization rule.
-
#rule_name ⇒ String
The name of the organization centralization rule.
-
#tag_propagation_failure_reason ⇒ String
The reason tag propagation is unhealthy for this rule.
-
#tag_propagation_status ⇒ String
The health status of tag propagation for this rule.
Instance Attribute Details
#centralization_rule ⇒ Types::CentralizationRule
The configuration details for the organization centralization rule.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#created_region ⇒ String
The Amazon Web Services region where the organization centralization rule was created.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#created_time_stamp ⇒ Integer
The timestamp when the organization centralization rule was created.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The Amazon Web Services Account that created the organization centralization rule.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason why an organization centralization rule is marked UNHEALTHY.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#last_update_time_stamp ⇒ Integer
The timestamp when the organization centralization rule was last updated.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the organization centralization rule.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#rule_health ⇒ String
The health status of the organization centralization rule.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
The name of the organization centralization rule.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#tag_propagation_failure_reason ⇒ String
The reason tag propagation is unhealthy for this rule. Only present
when TagPropagationStatus is Unhealthy.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |
#tag_propagation_status ⇒ String
The health status of tag propagation for this rule. This status is
independent of the overall RuleHealth for log delivery. Returns
Healthy when the most recent tag-propagation attempt succeeded, or
Unhealthy when the most recent attempt failed.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 906 class GetCentralizationRuleForOrganizationOutput < Struct.new( :rule_name, :rule_arn, :creator_account_id, :created_time_stamp, :created_region, :last_update_time_stamp, :rule_health, :failure_reason, :tag_propagation_status, :tag_propagation_failure_reason, :centralization_rule) SENSITIVE = [] include Aws::Structure end |