Class: Aws::ObservabilityAdmin::Types::GetTelemetryRuleForOrganizationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_time_stampInteger

The timestamp when the organization telemetry rule was created.

Returns:

  • (Integer)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#home_regionString

The Amazon Web Services Region where the organization telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.

Returns:

  • (String)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#is_replicatedBoolean

Indicates whether this organization telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.

Returns:

  • (Boolean)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_time_stampInteger

The timestamp when the organization telemetry rule was last updated.

Returns:

  • (Integer)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#region_statusesArray<Types::RegionStatus>

A list of per-region replication statuses for the organization telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.

Returns:



1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#rule_arnString

The Amazon Resource Name (ARN) of the organization telemetry rule.

Returns:

  • (String)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#rule_nameString

The name of the organization telemetry rule.

Returns:

  • (String)


1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end

#telemetry_ruleTypes::TelemetryRule

The configuration details of the organization telemetry rule.



1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1148

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule,
  :home_region,
  :is_replicated,
  :region_statuses)
  SENSITIVE = []
  include Aws::Structure
end