Class: Aws::ObservabilityAdmin::Types::GetTelemetryRuleOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::GetTelemetryRuleOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_time_stamp ⇒ Integer
The timestamp when the telemetry rule was created.
-
#home_region ⇒ String
The Amazon Web Services Region where the telemetry rule was originally created.
-
#is_replicated ⇒ Boolean
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region.
-
#last_update_time_stamp ⇒ Integer
The timestamp when the telemetry rule was last updated.
-
#region_statuses ⇒ Array<Types::RegionStatus>
A list of per-region replication statuses for the telemetry rule.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule.
-
#rule_name ⇒ String
The name of the telemetry rule.
-
#telemetry_rule ⇒ Types::TelemetryRule
The configuration details of the telemetry rule.
Instance Attribute Details
#created_time_stamp ⇒ Integer
The timestamp when the telemetry rule was created.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#home_region ⇒ String
The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#is_replicated ⇒ Boolean
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#last_update_time_stamp ⇒ Integer
The timestamp when the telemetry rule was last updated.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#region_statuses ⇒ Array<Types::RegionStatus>
A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
The name of the telemetry rule.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |
#telemetry_rule ⇒ Types::TelemetryRule
The configuration details of the telemetry rule.
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1217 class GetTelemetryRuleOutput < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :telemetry_rule, :home_region, :is_replicated, :region_statuses) SENSITIVE = [] include Aws::Structure end |