Class: Aws::ObservabilityAdmin::Types::LogDeliveryParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

The configuration parameters for log delivery, including logType settings. Applies to resource types that support configurable log delivery, such as Amazon Bedrock Knowledge Bases and Elastic Load Balancing Application Load Balancers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_typesArray<String>

The types of logs to collect from the resource.

Returns:

  • (Array<String>)


1701
1702
1703
1704
1705
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1701

class LogDeliveryParameters < Struct.new(
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end