Class: Aws::ObservabilityAdmin::Types::LogsEncryptionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Configuration for encrypting centralized destination log groups. By default, this configuration applies only to destination log groups whose corresponding source log groups are encrypted using customer managed KMS keys. To encrypt all destination log groups created by the rule, set EncryptionScope to NEW_DESTINATION_LOG_GROUPS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_conflict_resolution_strategyString

Conflict resolution strategy for centralization if the encryption strategy is set to CUSTOMER_MANAGED and the destination log group is encrypted with an AWS_OWNED KMS Key. ALLOW lets centralization go through while SKIP prevents centralization into the destination log group.

Returns:

  • (String)


1806
1807
1808
1809
1810
1811
1812
1813
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1806

class LogsEncryptionConfiguration < Struct.new(
  :encryption_strategy,
  :kms_key_arn,
  :encryption_conflict_resolution_strategy,
  :encryption_scope)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_scopeString

Determines which newly created destination log groups are encrypted with the configured KmsKeyArn when EncryptionStrategy is CUSTOMER_MANAGED.

If you set this to ENCRYPTED_SOURCE_ONLY (the default), only destination log groups whose source log group is encrypted with a customer managed KMS key use the configured KmsKeyArn. Destination log groups derived from Amazon Web Services owned encrypted source log groups remain Amazon Web Services owned encrypted.

If you set this to NEW_DESTINATION_LOG_GROUPS, every new destination log group created by this rule uses the configured KmsKeyArn, regardless of the source log group's encryption posture.

This field is not valid when EncryptionStrategy is AWS_OWNED.

Returns:

  • (String)


1806
1807
1808
1809
1810
1811
1812
1813
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1806

class LogsEncryptionConfiguration < Struct.new(
  :encryption_strategy,
  :kms_key_arn,
  :encryption_conflict_resolution_strategy,
  :encryption_scope)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_strategyString

Configuration that determines the encryption strategy of the destination log groups. CUSTOMER_MANAGED uses the configured KmsKeyArn to encrypt newly created destination log groups.

Returns:

  • (String)


1806
1807
1808
1809
1810
1811
1812
1813
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1806

class LogsEncryptionConfiguration < Struct.new(
  :encryption_strategy,
  :kms_key_arn,
  :encryption_conflict_resolution_strategy,
  :encryption_scope)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

KMS Key ARN belonging to the primary destination account and region, to encrypt newly created central log groups in the primary destination.

Returns:

  • (String)


1806
1807
1808
1809
1810
1811
1812
1813
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1806

class LogsEncryptionConfiguration < Struct.new(
  :encryption_strategy,
  :kms_key_arn,
  :encryption_conflict_resolution_strategy,
  :encryption_scope)
  SENSITIVE = []
  include Aws::Structure
end