Class: Aws::ObservabilityAdmin::Types::RegionStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::RegionStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Represents the status of a multi-region operation in a specific Amazon Web Services Region. This structure is used to report per-region progress for both telemetry evaluation and telemetry rule replication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_reason ⇒ String
The reason for a failure status in this region.
-
#region ⇒ String
The Amazon Web Services Region code (for example, ‘eu-west-1` or `us-west-2`) that this status applies to.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule in this spoke region.
-
#status ⇒ String
The status of the operation in this region.
Instance Attribute Details
#failure_reason ⇒ String
The reason for a failure status in this region. This field is only populated when ‘Status` indicates a failure.
1912 1913 1914 1915 1916 1917 1918 1919 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1912 class RegionStatus < Struct.new( :region, :status, :failure_reason, :rule_arn) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region code (for example, ‘eu-west-1` or `us-west-2`) that this status applies to.
1912 1913 1914 1915 1916 1917 1918 1919 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1912 class RegionStatus < Struct.new( :region, :status, :failure_reason, :rule_arn) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule in this spoke region. This field is only present for telemetry rule region statuses and is populated when the rule has been successfully created in the spoke region (status is ‘ACTIVE`).
1912 1913 1914 1915 1916 1917 1918 1919 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1912 class RegionStatus < Struct.new( :region, :status, :failure_reason, :rule_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the operation in this region. For telemetry evaluation, valid values include ‘STARTING`, `RUNNING`, and `FAILED_START`. For telemetry rules, valid values include `PENDING`, `ACTIVE`, and `FAILED`.
1912 1913 1914 1915 1916 1917 1918 1919 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1912 class RegionStatus < Struct.new( :region, :status, :failure_reason, :rule_arn) SENSITIVE = [] include Aws::Structure end |