Class: Aws::ObservabilityAdmin::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
The requested operation would exceed the allowed quota for the specified resource type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amzn_error_type ⇒ String
The name of the exception.
- #message ⇒ String
-
#quota_code ⇒ String
The code for the exceeded service quota.
-
#resource_id ⇒ String
The identifier of the resource which exceeds the service quota.
-
#resource_type ⇒ String
The type of the resource which exceeds the service quota.
-
#service_code ⇒ String
The code for the service of the exceeded quota.
Instance Attribute Details
#amzn_error_type ⇒ String
The name of the exception.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The code for the exceeded service quota.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the resource which exceeds the service quota.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource which exceeds the service quota.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The code for the service of the exceeded quota.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2031 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code, :amzn_error_type) SENSITIVE = [] include Aws::Structure end |