Class: Aws::ObservabilityAdmin::Types::SourceLogsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Configuration for selecting and handling source log groups for centralization.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_selection_criteriaString

The selection criteria that specifies which data sources to centralize. The selection criteria uses the same filter expression format as ‘LogGroupSelectionCriteria`, but operates on `DataSourceName` and `DataSourceType` operands. When both `LogGroupSelectionCriteria` and `DataSourceSelectionCriteria` are specified, a log event must match both criteria to be centralized.

Returns:

  • (String)


2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2042

class SourceLogsConfiguration < Struct.new(
  :log_group_selection_criteria,
  :data_source_selection_criteria,
  :encrypted_log_group_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#encrypted_log_group_strategyString

A strategy determining whether to centralize source log groups that are encrypted with customer managed KMS keys (CMK). ALLOW will consider CMK encrypted source log groups for centralization while SKIP will skip CMK encrypted source log groups from centralization.

Returns:

  • (String)


2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2042

class SourceLogsConfiguration < Struct.new(
  :log_group_selection_criteria,
  :data_source_selection_criteria,
  :encrypted_log_group_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_selection_criteriaString

The selection criteria that specifies which source log groups to centralize. The selection criteria uses the same format as OAM link filters.

Returns:

  • (String)


2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2042

class SourceLogsConfiguration < Struct.new(
  :log_group_selection_criteria,
  :data_source_selection_criteria,
  :encrypted_log_group_strategy)
  SENSITIVE = []
  include Aws::Structure
end