Class: Aws::ObservabilityAdmin::Types::StopTelemetryEnrichmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::StopTelemetryEnrichmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the resource tags for telemetry feature after the stop operation (
Running,Stopped, orImpaired).
Instance Attribute Details
#status ⇒ String
The status of the resource tags for telemetry feature after the stop
operation (Running, Stopped, or Impaired).
2150 2151 2152 2153 2154 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2150 class StopTelemetryEnrichmentOutput < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |