Class: Aws::ObservabilityAdmin::Types::TelemetryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::TelemetryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
A model representing the state of a resource within an account according to telemetry config.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_identifier ⇒ String
The account ID which contains the resource managed in telemetry configuration.
-
#last_update_time_stamp ⇒ Integer
The timestamp of the last change to the telemetry configuration for the resource.
-
#resource_identifier ⇒ String
The identifier of the resource, for example ‘i-0b22a22eec53b9321`.
-
#resource_tags ⇒ Hash<String,String>
Tags associated with the resource, for example ‘{ Name: “ExampleInstance”, Environment: “Development” }`.
-
#resource_type ⇒ String
The type of resource, for example ‘AWS::EC2::Instance`.
-
#telemetry_configuration_state ⇒ Hash<String,String>
The configuration state for the resource, for example ‘{ Logs: NotApplicable; Metrics: Enabled; Traces: NotApplicable; }`.
Instance Attribute Details
#account_identifier ⇒ String
The account ID which contains the resource managed in telemetry configuration. An example of a valid account ID is ‘012345678901`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |
#last_update_time_stamp ⇒ Integer
The timestamp of the last change to the telemetry configuration for the resource. For example, ‘1728679196318`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
The identifier of the resource, for example ‘i-0b22a22eec53b9321`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
Tags associated with the resource, for example ‘{ Name: “ExampleInstance”, Environment: “Development” }`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource, for example ‘AWS::EC2::Instance`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |
#telemetry_configuration_state ⇒ Hash<String,String>
The configuration state for the resource, for example ‘{ Logs: NotApplicable; Metrics: Enabled; Traces: NotApplicable; }`.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 273 class TelemetryConfiguration < Struct.new( :account_identifier, :telemetry_configuration_state, :resource_type, :resource_identifier, :resource_tags, :last_update_time_stamp) SENSITIVE = [] include Aws::Structure end |