Class: Aws::ObservabilityAdmin::Types::TelemetryDestinationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Configuration specifying where and how telemetry data should be delivered for Amazon Web Services resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloudtrail_parametersTypes::CloudtrailParameters

Configuration parameters specific to Amazon Web Services CloudTrail when CloudTrail is the source type.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#destination_patternString

The pattern used to generate the destination path or name, supporting macros like <resourceId> and <accountId>.

Returns:

  • (String)


2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#destination_typeString

The type of destination for the telemetry data (e.g., "Amazon CloudWatch Logs", "S3").

Returns:

  • (String)


2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#elb_load_balancer_logging_parametersTypes::ELBLoadBalancerLoggingParameters

Configuration parameters specific to ELB load balancer logging when ELB is the resource type.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the customer-managed Amazon Web Services KMS key used to encrypt the log groups created during telemetry rule remediation.

Returns:

  • (String)


2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_parametersTypes::LogDeliveryParameters

The configuration parameters for log delivery when the resource type supports configurable log types, such as Amazon Bedrock Knowledge Bases or Elastic Load Balancing Application Load Balancers.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#msk_monitoring_parametersTypes::MskMonitoringParameters

Configuration parameters specific to MSK monitoring when MSK is the resource type.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#retention_in_daysInteger

The number of days to retain the telemetry data in the destination.

Returns:

  • (Integer)


2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_flow_log_parametersTypes::VPCFlowLogParameters

Configuration parameters specific to VPC Flow Logs when VPC is the resource type.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#waf_logging_parametersTypes::WAFLoggingParameters

Configuration parameters specific to WAF logging when WAF is the resource type.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2380

class TelemetryDestinationConfiguration < Struct.new(
  :destination_type,
  :destination_pattern,
  :retention_in_days,
  :vpc_flow_log_parameters,
  :cloudtrail_parameters,
  :elb_load_balancer_logging_parameters,
  :waf_logging_parameters,
  :log_delivery_parameters,
  :msk_monitoring_parameters,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end