Class: Aws::ObservabilityAdmin::Types::TelemetryRuleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::TelemetryRuleSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
A summary of a telemetry rule's key properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_time_stamp ⇒ Integer
The timestamp when the telemetry rule was created.
-
#last_update_time_stamp ⇒ Integer
The timestamp when the telemetry rule was last modified.
-
#resource_type ⇒ String
The type of Amazon Web Services resource the rule applies to.
-
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule.
-
#rule_name ⇒ String
The name of the telemetry rule.
-
#telemetry_source_types ⇒ Array<String>
The types of telemetry sources configured for this rule, such as VPC Flow Logs or EKS audit logs.
-
#telemetry_type ⇒ String
The type of telemetry (Logs, Metrics, or Traces) the rule configures.
Instance Attribute Details
#created_time_stamp ⇒ Integer
The timestamp when the telemetry rule was created.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#last_update_time_stamp ⇒ Integer
The timestamp when the telemetry rule was last modified.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of Amazon Web Services resource the rule applies to.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#rule_arn ⇒ String
The Amazon Resource Name (ARN) of the telemetry rule.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
The name of the telemetry rule.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#telemetry_source_types ⇒ Array<String>
The types of telemetry sources configured for this rule, such as VPC Flow Logs or EKS audit logs. TelemetrySourceTypes must be correlated with the specific resource type.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |
#telemetry_type ⇒ String
The type of telemetry (Logs, Metrics, or Traces) the rule configures.
2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2594 class TelemetryRuleSummary < Struct.new( :rule_name, :rule_arn, :created_time_stamp, :last_update_time_stamp, :resource_type, :telemetry_type, :telemetry_source_types) SENSITIVE = [] include Aws::Structure end |