Class: Aws::ObservabilityAdmin::Types::UpdateTelemetryRuleForOrganizationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ruleTypes::TelemetryRule

The new configuration details for the organization telemetry rule, including resource type, telemetry type, and destination configuration.



2645
2646
2647
2648
2649
2650
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2645

class UpdateTelemetryRuleForOrganizationInput < Struct.new(
  :rule_identifier,
  :rule)
  SENSITIVE = []
  include Aws::Structure
end

#rule_identifierString

The identifier (name or ARN) of the organization telemetry rule to update.

Returns:

  • (String)


2645
2646
2647
2648
2649
2650
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2645

class UpdateTelemetryRuleForOrganizationInput < Struct.new(
  :rule_identifier,
  :rule)
  SENSITIVE = []
  include Aws::Structure
end