Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization.
-
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics.
-
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data.
-
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account.
-
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization.
-
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule.
-
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data.
-
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources.
-
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account.
-
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule.
-
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule.
-
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
-
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
-
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
-
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule.
-
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
-
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource.
-
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account.
-
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account.
-
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization.
-
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource.
-
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization.
-
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
-
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
-
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization.
-
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2638 2639 2640 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2638 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2641 2642 2643 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2641 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2611 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
553 554 555 556 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 553 def create_centralization_rule_for_organization(params = {}, = {}) req = build_request(:create_centralization_rule_for_organization, params) req.send_request() end |
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics. This integration enables querying CloudWatch telemetry data using analytics engines like Amazon Athena, Amazon Redshift, and Apache Spark.
600 601 602 603 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 600 def create_s3_table_integration(params = {}, = {}) req = build_request(:create_s3_table_integration, params) req.send_request() end |
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
652 653 654 655 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 652 def create_telemetry_pipeline(params = {}, = {}) req = build_request(:create_telemetry_pipeline, params) req.send_request() end |
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
776 777 778 779 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 776 def create_telemetry_rule(params = {}, = {}) req = build_request(:create_telemetry_rule, params) req.send_request() end |
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
899 900 901 902 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 899 def create_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:create_telemetry_rule_for_organization, params) req.send_request() end |
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
924 925 926 927 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 924 def delete_centralization_rule_for_organization(params = {}, = {}) req = build_request(:delete_centralization_rule_for_organization, params) req.send_request() end |
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data. This operation removes the connection between CloudWatch Observability Admin and S3 Tables.
948 949 950 951 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 948 def delete_s3_table_integration(params = {}, = {}) req = build_request(:delete_s3_table_integration, params) req.send_request() end |
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources. This operation stops data processing and removes the pipeline configuration.
972 973 974 975 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 972 def delete_telemetry_pipeline(params = {}, = {}) req = build_request(:delete_telemetry_pipeline, params) req.send_request() end |
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
996 997 998 999 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 996 def delete_telemetry_rule(params = {}, = {}) req = build_request(:delete_telemetry_rule, params) req.send_request() end |
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1021 1022 1023 1024 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1021 def delete_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:delete_telemetry_rule_for_organization, params) req.send_request() end |
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1083 1084 1085 1086 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1083 def get_centralization_rule_for_organization(params = {}, = {}) req = build_request(:get_centralization_rule_for_organization, params) req.send_request() end |
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
1124 1125 1126 1127 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1124 def get_s3_table_integration(params = {}, = {}) req = build_request(:get_s3_table_integration, params) req.send_request() end |
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1147 def get_telemetry_enrichment_status(params = {}, = {}) req = build_request(:get_telemetry_enrichment_status, params) req.send_request() end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
1178 1179 1180 1181 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1178 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
1210 1211 1212 1213 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1210 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
1247 1248 1249 1250 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1247 def get_telemetry_pipeline(params = {}, = {}) req = build_request(:get_telemetry_pipeline, params) req.send_request() end |
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
1342 1343 1344 1345 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1342 def get_telemetry_rule(params = {}, = {}) req = build_request(:get_telemetry_rule, params) req.send_request() end |
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1440 def get_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:get_telemetry_rule_for_organization, params) req.send_request() end |
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1500 1501 1502 1503 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1500 def list_centralization_rules_for_organization(params = {}, = {}) req = build_request(:list_centralization_rules_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1583 1584 1585 1586 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1583 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1667 1668 1669 1670 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1667 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1709 1710 1711 1712 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1709 def list_s3_table_integrations(params = {}, = {}) req = build_request(:list_s3_table_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource. Supports telemetry rule resources and telemetry pipeline resources.
1740 1741 1742 1743 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1740 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account. Returns up to 100 results. If more than 100 telemetry pipelines exist, include the ‘NextToken` value from the response to retrieve the next set of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1797 1798 1799 1800 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1797 def list_telemetry_pipelines(params = {}, = {}) req = build_request(:list_telemetry_pipelines, params) req.send_request() end |
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1848 1849 1850 1851 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1848 def list_telemetry_rules(params = {}, = {}) req = build_request(:list_telemetry_rules, params) req.send_request() end |
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1911 1912 1913 1914 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1911 def list_telemetry_rules_for_organization(params = {}, = {}) req = build_request(:list_telemetry_rules_for_organization, params) req.send_request() end |
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
1935 1936 1937 1938 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1935 def start_telemetry_enrichment(params = {}, = {}) req = build_request(:start_telemetry_enrichment, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
1973 1974 1975 1976 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1973 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
2012 2013 2014 2015 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2012 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
2033 2034 2035 2036 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2033 def stop_telemetry_enrichment(params = {}, = {}) req = build_request(:stop_telemetry_enrichment, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
2047 2048 2049 2050 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2047 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
2061 2062 2063 2064 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2061 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource. Supports telemetry rule resources and telemetry pipeline resources.
2090 2091 2092 2093 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2090 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment. This operation helps ensure your pipeline configuration works as expected.
2135 2136 2137 2138 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2135 def test_telemetry_pipeline(params = {}, = {}) req = build_request(:test_telemetry_pipeline, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.
2163 2164 2165 2166 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2163 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2237 2238 2239 2240 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2237 def update_centralization_rule_for_organization(params = {}, = {}) req = build_request(:update_centralization_rule_for_organization, params) req.send_request() end |
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
<note markdown=“1”> The following attributes cannot be updated after pipeline creation:
* **Pipeline name** - The pipeline name is immutable
-
**Pipeline ARN** - The ARN is automatically generated and cannot be changed
-
**Source type** - Once a pipeline is created with a specific source type (such as S3, CloudWatch Logs, GitHub, or third-party sources), it cannot be changed to a different source type
Processors can be added, removed, or modified. However, some
processors are not supported for third-party pipelines and cannot be added through updates.
</note>
**Source-Specific Update Rules**
CloudWatch Logs Sources (Vended and Custom)
: Updatable: ‘sts_role_arn`
**Fixed:** `data_source_name`, `data_source_type`, sink (must remain
`@original`)
S3 Sources (Crowdstrike, Zscaler, SentinelOne, Custom)
: Updatable: All SQS configuration parameters, ‘sts_role_arn`,
codec settings, compression type, bucket ownership settings, sink
log group
**Fixed:** `notification_type`, `aws.region`
GitHub Audit Logs
: Updatable: All Amazon Web Services Secrets Manager attributes,
`scope` (can switch between ORGANIZATION/ENTERPRISE), `organization`
or `enterprise` name, `range`, authentication credentials (PAT or
GitHub App)
Microsoft Sources (Entra ID, Office365, Windows)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`tenant_id`, `workspace_id` (Windows only), OAuth2 credentials
(`client_id`, `client_secret`)
Okta Sources (SSO, Auth0)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`domain`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
Palo Alto Networks
: Updatable: All Amazon Web Services Secrets Manager attributes,
`hostname`, basic authentication credentials (`username`,
`password`)
ServiceNow CMDB
: Updatable: All Amazon Web Services Secrets Manager attributes,
`instance_url`, `range`, OAuth2 credentials (`client_id`,
`client_secret`)
Wiz CNAPP
: Updatable: All Amazon Web Services Secrets Manager attributes,
`region`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
2335 2336 2337 2338 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2335 def update_telemetry_pipeline(params = {}, = {}) req = build_request(:update_telemetry_pipeline, params) req.send_request() end |
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.
2449 2450 2451 2452 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2449 def update_telemetry_rule(params = {}, = {}) req = build_request(:update_telemetry_rule, params) req.send_request() end |
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2566 2567 2568 2569 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2566 def update_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:update_telemetry_rule_for_organization, params) req.send_request() end |
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline. This operation checks the configuration for syntax errors and compatibility issues.
2602 2603 2604 2605 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2602 def validate_telemetry_pipeline_configuration(params = {}, = {}) req = build_request(:validate_telemetry_pipeline_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2631 2632 2633 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2631 def waiter_names [] end |