Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization.
-
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics.
-
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data.
-
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account.
-
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization.
-
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule.
-
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data.
-
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources.
-
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account.
-
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule.
-
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule.
-
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
-
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
-
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
-
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule.
-
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
-
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource.
-
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account.
-
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account.
-
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization.
-
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource.
-
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization.
-
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
-
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
-
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization.
-
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2622 2623 2624 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2622 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2625 2626 2627 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2625 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2595 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.27.0' Seahorse::Client::Request.new(handlers, context) end |
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
547 548 549 550 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 547 def create_centralization_rule_for_organization(params = {}, = {}) req = build_request(:create_centralization_rule_for_organization, params) req.send_request() end |
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics. This integration enables querying CloudWatch telemetry data using analytics engines like Amazon Athena, Amazon Redshift, and Apache Spark.
594 595 596 597 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 594 def create_s3_table_integration(params = {}, = {}) req = build_request(:create_s3_table_integration, params) req.send_request() end |
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
646 647 648 649 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 646 def create_telemetry_pipeline(params = {}, = {}) req = build_request(:create_telemetry_pipeline, params) req.send_request() end |
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
770 771 772 773 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 770 def create_telemetry_rule(params = {}, = {}) req = build_request(:create_telemetry_rule, params) req.send_request() end |
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
893 894 895 896 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 893 def create_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:create_telemetry_rule_for_organization, params) req.send_request() end |
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
918 919 920 921 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 918 def delete_centralization_rule_for_organization(params = {}, = {}) req = build_request(:delete_centralization_rule_for_organization, params) req.send_request() end |
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data. This operation removes the connection between CloudWatch Observability Admin and S3 Tables.
942 943 944 945 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 942 def delete_s3_table_integration(params = {}, = {}) req = build_request(:delete_s3_table_integration, params) req.send_request() end |
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources. This operation stops data processing and removes the pipeline configuration.
966 967 968 969 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 966 def delete_telemetry_pipeline(params = {}, = {}) req = build_request(:delete_telemetry_pipeline, params) req.send_request() end |
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
990 991 992 993 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 990 def delete_telemetry_rule(params = {}, = {}) req = build_request(:delete_telemetry_rule, params) req.send_request() end |
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1015 1016 1017 1018 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1015 def delete_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:delete_telemetry_rule_for_organization, params) req.send_request() end |
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1075 1076 1077 1078 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1075 def get_centralization_rule_for_organization(params = {}, = {}) req = build_request(:get_centralization_rule_for_organization, params) req.send_request() end |
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1116 def get_s3_table_integration(params = {}, = {}) req = build_request(:get_s3_table_integration, params) req.send_request() end |
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1139 def get_telemetry_enrichment_status(params = {}, = {}) req = build_request(:get_telemetry_enrichment_status, params) req.send_request() end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
1170 1171 1172 1173 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1170 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
1202 1203 1204 1205 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1202 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
1239 1240 1241 1242 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1239 def get_telemetry_pipeline(params = {}, = {}) req = build_request(:get_telemetry_pipeline, params) req.send_request() end |
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
1334 1335 1336 1337 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1334 def get_telemetry_rule(params = {}, = {}) req = build_request(:get_telemetry_rule, params) req.send_request() end |
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1432 1433 1434 1435 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1432 def get_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:get_telemetry_rule_for_organization, params) req.send_request() end |
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1492 1493 1494 1495 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1492 def list_centralization_rules_for_organization(params = {}, = {}) req = build_request(:list_centralization_rules_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1575 1576 1577 1578 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1575 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1659 1660 1661 1662 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1659 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1701 1702 1703 1704 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1701 def list_s3_table_integrations(params = {}, = {}) req = build_request(:list_s3_table_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource. Supports telemetry rule resources and telemetry pipeline resources.
1732 1733 1734 1735 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1732 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account. Returns up to 100 results. If more than 100 telemetry pipelines exist, include the ‘NextToken` value from the response to retrieve the next set of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1789 1790 1791 1792 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1789 def list_telemetry_pipelines(params = {}, = {}) req = build_request(:list_telemetry_pipelines, params) req.send_request() end |
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1840 1841 1842 1843 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1840 def list_telemetry_rules(params = {}, = {}) req = build_request(:list_telemetry_rules, params) req.send_request() end |
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1903 1904 1905 1906 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1903 def list_telemetry_rules_for_organization(params = {}, = {}) req = build_request(:list_telemetry_rules_for_organization, params) req.send_request() end |
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
1927 1928 1929 1930 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1927 def start_telemetry_enrichment(params = {}, = {}) req = build_request(:start_telemetry_enrichment, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
1965 1966 1967 1968 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1965 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
2004 2005 2006 2007 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2004 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
2025 2026 2027 2028 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2025 def stop_telemetry_enrichment(params = {}, = {}) req = build_request(:stop_telemetry_enrichment, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
2039 2040 2041 2042 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2039 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
2053 2054 2055 2056 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2053 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource. Supports telemetry rule resources and telemetry pipeline resources.
2082 2083 2084 2085 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2082 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment. This operation helps ensure your pipeline configuration works as expected.
2127 2128 2129 2130 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2127 def test_telemetry_pipeline(params = {}, = {}) req = build_request(:test_telemetry_pipeline, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.
2155 2156 2157 2158 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2155 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2221 2222 2223 2224 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2221 def update_centralization_rule_for_organization(params = {}, = {}) req = build_request(:update_centralization_rule_for_organization, params) req.send_request() end |
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
<note markdown=“1”> The following attributes cannot be updated after pipeline creation:
* **Pipeline name** - The pipeline name is immutable
-
**Pipeline ARN** - The ARN is automatically generated and cannot be changed
-
**Source type** - Once a pipeline is created with a specific source type (such as S3, CloudWatch Logs, GitHub, or third-party sources), it cannot be changed to a different source type
Processors can be added, removed, or modified. However, some
processors are not supported for third-party pipelines and cannot be added through updates.
</note>
**Source-Specific Update Rules**
CloudWatch Logs Sources (Vended and Custom)
: Updatable: ‘sts_role_arn`
**Fixed:** `data_source_name`, `data_source_type`, sink (must remain
`@original`)
S3 Sources (Crowdstrike, Zscaler, SentinelOne, Custom)
: Updatable: All SQS configuration parameters, ‘sts_role_arn`,
codec settings, compression type, bucket ownership settings, sink
log group
**Fixed:** `notification_type`, `aws.region`
GitHub Audit Logs
: Updatable: All Amazon Web Services Secrets Manager attributes,
`scope` (can switch between ORGANIZATION/ENTERPRISE), `organization`
or `enterprise` name, `range`, authentication credentials (PAT or
GitHub App)
Microsoft Sources (Entra ID, Office365, Windows)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`tenant_id`, `workspace_id` (Windows only), OAuth2 credentials
(`client_id`, `client_secret`)
Okta Sources (SSO, Auth0)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`domain`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
Palo Alto Networks
: Updatable: All Amazon Web Services Secrets Manager attributes,
`hostname`, basic authentication credentials (`username`,
`password`)
ServiceNow CMDB
: Updatable: All Amazon Web Services Secrets Manager attributes,
`instance_url`, `range`, OAuth2 credentials (`client_id`,
`client_secret`)
Wiz CNAPP
: Updatable: All Amazon Web Services Secrets Manager attributes,
`region`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
2319 2320 2321 2322 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2319 def update_telemetry_pipeline(params = {}, = {}) req = build_request(:update_telemetry_pipeline, params) req.send_request() end |
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.
2433 2434 2435 2436 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2433 def update_telemetry_rule(params = {}, = {}) req = build_request(:update_telemetry_rule, params) req.send_request() end |
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2550 2551 2552 2553 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2550 def update_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:update_telemetry_rule_for_organization, params) req.send_request() end |
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline. This operation checks the configuration for syntax errors and compatibility issues.
2586 2587 2588 2589 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2586 def validate_telemetry_pipeline_configuration(params = {}, = {}) req = build_request(:validate_telemetry_pipeline_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2615 2616 2617 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2615 def waiter_names [] end |