Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization.
-
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics.
-
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data.
-
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account.
-
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization.
-
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule.
-
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data.
-
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources.
-
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account.
-
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule.
-
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule.
-
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
-
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
-
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
-
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule.
-
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
-
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource.
-
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account.
-
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account.
-
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization.
-
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource.
-
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization.
-
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
-
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
-
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization.
-
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2608 2609 2610 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2608 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2611 2612 2613 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2611 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2581 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#create_centralization_rule_for_organization(params = {}) ⇒ Types::CreateCentralizationRuleForOrganizationOutput
Creates a centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
547 548 549 550 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 547 def create_centralization_rule_for_organization(params = {}, = {}) req = build_request(:create_centralization_rule_for_organization, params) req.send_request() end |
#create_s3_table_integration(params = {}) ⇒ Types::CreateS3TableIntegrationOutput
Creates an integration between CloudWatch and S3 Tables for analytics. This integration enables querying CloudWatch telemetry data using analytics engines like Amazon Athena, Amazon Redshift, and Apache Spark.
594 595 596 597 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 594 def create_s3_table_integration(params = {}, = {}) req = build_request(:create_s3_table_integration, params) req.send_request() end |
#create_telemetry_pipeline(params = {}) ⇒ Types::CreateTelemetryPipelineOutput
Creates a telemetry pipeline for processing and transforming telemetry data. The pipeline defines how data flows from sources through processors to destinations, enabling data transformation and delivering capabilities.
646 647 648 649 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 646 def create_telemetry_pipeline(params = {}, = {}) req = build_request(:create_telemetry_pipeline, params) req.send_request() end |
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
767 768 769 770 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 767 def create_telemetry_rule(params = {}, = {}) req = build_request(:create_telemetry_rule, params) req.send_request() end |
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
887 888 889 890 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 887 def create_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:create_telemetry_rule_for_organization, params) req.send_request() end |
#delete_centralization_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
912 913 914 915 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 912 def delete_centralization_rule_for_organization(params = {}, = {}) req = build_request(:delete_centralization_rule_for_organization, params) req.send_request() end |
#delete_s3_table_integration(params = {}) ⇒ Struct
Deletes an S3 Table integration and its associated data. This operation removes the connection between CloudWatch Observability Admin and S3 Tables.
936 937 938 939 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 936 def delete_s3_table_integration(params = {}, = {}) req = build_request(:delete_s3_table_integration, params) req.send_request() end |
#delete_telemetry_pipeline(params = {}) ⇒ Struct
Deletes a telemetry pipeline and its associated resources. This operation stops data processing and removes the pipeline configuration.
960 961 962 963 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 960 def delete_telemetry_pipeline(params = {}, = {}) req = build_request(:delete_telemetry_pipeline, params) req.send_request() end |
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
984 985 986 987 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 984 def delete_telemetry_rule(params = {}, = {}) req = build_request(:delete_telemetry_rule, params) req.send_request() end |
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1009 1010 1011 1012 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1009 def delete_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:delete_telemetry_rule_for_organization, params) req.send_request() end |
#get_centralization_rule_for_organization(params = {}) ⇒ Types::GetCentralizationRuleForOrganizationOutput
Retrieves the details of a specific organization centralization rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1069 1070 1071 1072 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1069 def get_centralization_rule_for_organization(params = {}, = {}) req = build_request(:get_centralization_rule_for_organization, params) req.send_request() end |
#get_s3_table_integration(params = {}) ⇒ Types::GetS3TableIntegrationOutput
Retrieves information about a specific S3 Table integration, including its configuration, status, and metadata.
1110 1111 1112 1113 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1110 def get_s3_table_integration(params = {}, = {}) req = build_request(:get_s3_table_integration, params) req.send_request() end |
#get_telemetry_enrichment_status(params = {}) ⇒ Types::GetTelemetryEnrichmentStatusOutput
Returns the current status of the resource tags for telemetry feature, which enhances telemetry data with additional resource metadata from Resource Explorer.
1133 1134 1135 1136 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1133 def get_telemetry_enrichment_status(params = {}, = {}) req = build_request(:get_telemetry_enrichment_status, params) req.send_request() end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
1164 1165 1166 1167 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1164 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
1196 1197 1198 1199 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1196 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#get_telemetry_pipeline(params = {}) ⇒ Types::GetTelemetryPipelineOutput
Retrieves information about a specific telemetry pipeline, including its configuration, status, and metadata.
1233 1234 1235 1236 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1233 def get_telemetry_pipeline(params = {}, = {}) req = build_request(:get_telemetry_pipeline, params) req.send_request() end |
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1327 def get_telemetry_rule(params = {}, = {}) req = build_request(:get_telemetry_rule, params) req.send_request() end |
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
1424 1425 1426 1427 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1424 def get_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:get_telemetry_rule_for_organization, params) req.send_request() end |
#list_centralization_rules_for_organization(params = {}) ⇒ Types::ListCentralizationRulesForOrganizationOutput
Lists all centralization rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1484 1485 1486 1487 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1484 def list_centralization_rules_for_organization(params = {}, = {}) req = build_request(:list_centralization_rules_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1567 1568 1569 1570 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1567 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1651 1652 1653 1654 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1651 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#list_s3_table_integrations(params = {}) ⇒ Types::ListS3TableIntegrationsOutput
Lists all S3 Table integrations in your account. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1693 1694 1695 1696 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1693 def list_s3_table_integrations(params = {}, = {}) req = build_request(:list_s3_table_integrations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified resource. Supports telemetry rule resources and telemetry pipeline resources.
1724 1725 1726 1727 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1724 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_telemetry_pipelines(params = {}) ⇒ Types::ListTelemetryPipelinesOutput
Returns a list of telemetry pipelines in your account. Returns up to 100 results. If more than 100 telemetry pipelines exist, include the ‘NextToken` value from the response to retrieve the next set of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1781 1782 1783 1784 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1781 def list_telemetry_pipelines(params = {}, = {}) req = build_request(:list_telemetry_pipelines, params) req.send_request() end |
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1832 1833 1834 1835 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1832 def list_telemetry_rules(params = {}, = {}) req = build_request(:list_telemetry_rules, params) req.send_request() end |
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1895 1896 1897 1898 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1895 def list_telemetry_rules_for_organization(params = {}, = {}) req = build_request(:list_telemetry_rules_for_organization, params) req.send_request() end |
#start_telemetry_enrichment(params = {}) ⇒ Types::StartTelemetryEnrichmentOutput
Enables the resource tags for telemetry feature for your account, which enhances telemetry data with additional resource metadata from Resource Explorer to provide richer context for monitoring and observability.
1919 1920 1921 1922 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1919 def start_telemetry_enrichment(params = {}, = {}) req = build_request(:start_telemetry_enrichment, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
1957 1958 1959 1960 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1957 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
1996 1997 1998 1999 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1996 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_enrichment(params = {}) ⇒ Types::StopTelemetryEnrichmentOutput
Disables the resource tags for telemetry feature for your account, stopping the enhancement of telemetry data with additional resource metadata.
2017 2018 2019 2020 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2017 def stop_telemetry_enrichment(params = {}, = {}) req = build_request(:stop_telemetry_enrichment, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
2031 2032 2033 2034 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2031 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
2045 2046 2047 2048 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2045 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource. Supports telemetry rule resources and telemetry pipeline resources.
2074 2075 2076 2077 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2074 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_telemetry_pipeline(params = {}) ⇒ Types::TestTelemetryPipelineOutput
Tests a pipeline configuration with sample records to validate data processing before deployment. This operation helps ensure your pipeline configuration works as expected.
2119 2120 2121 2122 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2119 def test_telemetry_pipeline(params = {}, = {}) req = build_request(:test_telemetry_pipeline, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource. Supports telemetry rule resources and telemetry pipeline resources.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2147 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_centralization_rule_for_organization(params = {}) ⇒ Types::UpdateCentralizationRuleForOrganizationOutput
Updates an existing centralization rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2213 2214 2215 2216 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2213 def update_centralization_rule_for_organization(params = {}, = {}) req = build_request(:update_centralization_rule_for_organization, params) req.send_request() end |
#update_telemetry_pipeline(params = {}) ⇒ Struct
Updates the configuration of an existing telemetry pipeline.
<note markdown=“1”> The following attributes cannot be updated after pipeline creation:
* **Pipeline name** - The pipeline name is immutable
-
**Pipeline ARN** - The ARN is automatically generated and cannot be changed
-
**Source type** - Once a pipeline is created with a specific source type (such as S3, CloudWatch Logs, GitHub, or third-party sources), it cannot be changed to a different source type
Processors can be added, removed, or modified. However, some
processors are not supported for third-party pipelines and cannot be added through updates.
</note>
**Source-Specific Update Rules**
CloudWatch Logs Sources (Vended and Custom)
: Updatable: ‘sts_role_arn`
**Fixed:** `data_source_name`, `data_source_type`, sink (must remain
`@original`)
S3 Sources (Crowdstrike, Zscaler, SentinelOne, Custom)
: Updatable: All SQS configuration parameters, ‘sts_role_arn`,
codec settings, compression type, bucket ownership settings, sink
log group
**Fixed:** `notification_type`, `aws.region`
GitHub Audit Logs
: Updatable: All Amazon Web Services Secrets Manager attributes,
`scope` (can switch between ORGANIZATION/ENTERPRISE), `organization`
or `enterprise` name, `range`, authentication credentials (PAT or
GitHub App)
Microsoft Sources (Entra ID, Office365, Windows)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`tenant_id`, `workspace_id` (Windows only), OAuth2 credentials
(`client_id`, `client_secret`)
Okta Sources (SSO, Auth0)
: Updatable: All Amazon Web Services Secrets Manager attributes,
`domain`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
Palo Alto Networks
: Updatable: All Amazon Web Services Secrets Manager attributes,
`hostname`, basic authentication credentials (`username`,
`password`)
ServiceNow CMDB
: Updatable: All Amazon Web Services Secrets Manager attributes,
`instance_url`, `range`, OAuth2 credentials (`client_id`,
`client_secret`)
Wiz CNAPP
: Updatable: All Amazon Web Services Secrets Manager attributes,
`region`, `range`, OAuth2 credentials (`client_id`, `client_secret`)
2311 2312 2313 2314 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2311 def update_telemetry_pipeline(params = {}, = {}) req = build_request(:update_telemetry_pipeline, params) req.send_request() end |
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account. If multiple users attempt to modify the same telemetry rule simultaneously, a ConflictException is returned to provide specific error information for concurrent modification scenarios.
2422 2423 2424 2425 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2422 def update_telemetry_rule(params = {}, = {}) req = build_request(:update_telemetry_rule, params) req.send_request() end |
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
2536 2537 2538 2539 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2536 def update_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:update_telemetry_rule_for_organization, params) req.send_request() end |
#validate_telemetry_pipeline_configuration(params = {}) ⇒ Types::ValidateTelemetryPipelineConfigurationOutput
Validates a pipeline configuration without creating the pipeline. This operation checks the configuration for syntax errors and compatibility issues.
2572 2573 2574 2575 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2572 def validate_telemetry_pipeline_configuration(params = {}, = {}) req = build_request(:validate_telemetry_pipeline_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2601 2602 2603 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 2601 def waiter_names [] end |