Class: Aws::ObservabilityAdmin::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-observabilityadmin/client.rb

Overview

An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::ObservabilityAdmin::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be an instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be an instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::ObservabilityAdmin::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::ObservabilityAdmin::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



476
477
478
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 476

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1337
1338
1339
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1337

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1340
1341
1342
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1340

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1310

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-observabilityadmin'
  context[:gem_version] = '1.9.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput

Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.

Examples:

Request syntax with placeholder values


resp = client.create_telemetry_rule({
  rule_name: "RuleName", # required
  rule: { # required
    resource_type: "AWS::EC2::Instance", # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
    telemetry_type: "Logs", # required, accepts Logs, Metrics, Traces
    destination_configuration: {
      destination_type: "cloud-watch-logs", # accepts cloud-watch-logs
      destination_pattern: "String",
      retention_in_days: 1,
      vpc_flow_log_parameters: {
        log_format: "String",
        traffic_type: "String",
        max_aggregation_interval: 1,
      },
    },
    scope: "String",
    selection_criteria: "String",
  },
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.rule_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_name (required, String)

    A unique name for the telemetry rule being created.

  • :rule (required, Types::TelemetryRule)

    The configuration details for the telemetry rule, including the resource type, telemetry type, destination configuration, and selection criteria for which resources the rule applies to.

  • :tags (Hash<String,String>)

    The key-value pairs to associate with the telemetry rule resource for categorization and management purposes.

Returns:

See Also:



537
538
539
540
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 537

def create_telemetry_rule(params = {}, options = {})
  req = build_request(:create_telemetry_rule, params)
  req.send_request(options)
end

#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput

Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.

Examples:

Request syntax with placeholder values


resp = client.create_telemetry_rule_for_organization({
  rule_name: "RuleName", # required
  rule: { # required
    resource_type: "AWS::EC2::Instance", # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
    telemetry_type: "Logs", # required, accepts Logs, Metrics, Traces
    destination_configuration: {
      destination_type: "cloud-watch-logs", # accepts cloud-watch-logs
      destination_pattern: "String",
      retention_in_days: 1,
      vpc_flow_log_parameters: {
        log_format: "String",
        traffic_type: "String",
        max_aggregation_interval: 1,
      },
    },
    scope: "String",
    selection_criteria: "String",
  },
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.rule_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_name (required, String)

    A unique name for the organization-wide telemetry rule being created.

  • :rule (required, Types::TelemetryRule)

    The configuration details for the organization-wide telemetry rule, including the resource type, telemetry type, destination configuration, and selection criteria for which resources the rule applies to across the organization.

  • :tags (Hash<String,String>)

    The key-value pairs to associate with the organization telemetry rule resource for categorization and management purposes.

Returns:

See Also:



596
597
598
599
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 596

def create_telemetry_rule_for_organization(params = {}, options = {})
  req = build_request(:create_telemetry_rule_for_organization, params)
  req.send_request(options)
end

#delete_telemetry_rule(params = {}) ⇒ Struct

Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.

Examples:

Request syntax with placeholder values


resp = client.delete_telemetry_rule({
  rule_identifier: "RuleIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the telemetry rule to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



620
621
622
623
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 620

def delete_telemetry_rule(params = {}, options = {})
  req = build_request(:delete_telemetry_rule, params)
  req.send_request(options)
end

#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct

Deletes an organization-wide telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.

Examples:

Request syntax with placeholder values


resp = client.delete_telemetry_rule_for_organization({
  rule_identifier: "RuleIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the organization telemetry rule to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



645
646
647
648
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 645

def delete_telemetry_rule_for_organization(params = {}, options = {})
  req = build_request(:delete_telemetry_rule_for_organization, params)
  req.send_request(options)
end

#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput

Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.

Examples:

Response structure


resp.status #=> String, one of "NOT_STARTED", "STARTING", "FAILED_START", "RUNNING", "STOPPING", "FAILED_STOP", "STOPPED"
resp.failure_reason #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

See Also:



668
669
670
671
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 668

def get_telemetry_evaluation_status(params = {}, options = {})
  req = build_request(:get_telemetry_evaluation_status, params)
  req.send_request(options)
end

#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput

This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.

Examples:

Response structure


resp.status #=> String, one of "NOT_STARTED", "STARTING", "FAILED_START", "RUNNING", "STOPPING", "FAILED_STOP", "STOPPED"
resp.failure_reason #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

See Also:



692
693
694
695
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 692

def get_telemetry_evaluation_status_for_organization(params = {}, options = {})
  req = build_request(:get_telemetry_evaluation_status_for_organization, params)
  req.send_request(options)
end

#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput

Retrieves the details of a specific telemetry rule in your account.

Examples:

Request syntax with placeholder values


resp = client.get_telemetry_rule({
  rule_identifier: "RuleIdentifier", # required
})

Response structure


resp.rule_name #=> String
resp.rule_arn #=> String
resp.created_time_stamp #=> Integer
resp.last_update_time_stamp #=> Integer
resp.telemetry_rule.resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_rule.telemetry_type #=> String, one of "Logs", "Metrics", "Traces"
resp.telemetry_rule.destination_configuration.destination_type #=> String, one of "cloud-watch-logs"
resp.telemetry_rule.destination_configuration.destination_pattern #=> String
resp.telemetry_rule.destination_configuration.retention_in_days #=> Integer
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.log_format #=> String
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.traffic_type #=> String
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.max_aggregation_interval #=> Integer
resp.telemetry_rule.scope #=> String
resp.telemetry_rule.selection_criteria #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the telemetry rule to retrieve.

Returns:

See Also:



737
738
739
740
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 737

def get_telemetry_rule(params = {}, options = {})
  req = build_request(:get_telemetry_rule, params)
  req.send_request(options)
end

#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput

Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.

Examples:

Request syntax with placeholder values


resp = client.get_telemetry_rule_for_organization({
  rule_identifier: "RuleIdentifier", # required
})

Response structure


resp.rule_name #=> String
resp.rule_arn #=> String
resp.created_time_stamp #=> Integer
resp.last_update_time_stamp #=> Integer
resp.telemetry_rule.resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_rule.telemetry_type #=> String, one of "Logs", "Metrics", "Traces"
resp.telemetry_rule.destination_configuration.destination_type #=> String, one of "cloud-watch-logs"
resp.telemetry_rule.destination_configuration.destination_pattern #=> String
resp.telemetry_rule.destination_configuration.retention_in_days #=> Integer
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.log_format #=> String
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.traffic_type #=> String
resp.telemetry_rule.destination_configuration.vpc_flow_log_parameters.max_aggregation_interval #=> Integer
resp.telemetry_rule.scope #=> String
resp.telemetry_rule.selection_criteria #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the organization telemetry rule to retrieve.

Returns:

See Also:



785
786
787
788
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 785

def get_telemetry_rule_for_organization(params = {}, options = {})
  req = build_request(:get_telemetry_rule_for_organization, params)
  req.send_request(options)
end

#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput

Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_resource_telemetry({
  resource_identifier_prefix: "ResourceIdentifierPrefix",
  resource_types: ["AWS::EC2::Instance"], # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
  telemetry_configuration_state: {
    "Logs" => "Enabled", # accepts Enabled, Disabled, NotApplicable
  },
  resource_tags: {
    "TagKey" => "TagValue",
  },
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.telemetry_configurations #=> Array
resp.telemetry_configurations[0]. #=> String
resp.telemetry_configurations[0].telemetry_configuration_state #=> Hash
resp.telemetry_configurations[0].telemetry_configuration_state["TelemetryType"] #=> String, one of "Enabled", "Disabled", "NotApplicable"
resp.telemetry_configurations[0].resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_configurations[0].resource_identifier #=> String
resp.telemetry_configurations[0].resource_tags #=> Hash
resp.telemetry_configurations[0].resource_tags["String"] #=> String
resp.telemetry_configurations[0].last_update_time_stamp #=> Integer
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_identifier_prefix (String)

    A string used to filter resources which have a ‘ResourceIdentifier` starting with the `ResourceIdentifierPrefix`.

  • :resource_types (Array<String>)

    A list of resource types used to filter resources supported by telemetry config. If this parameter is provided, the resources will be returned in the same order used in the request.

  • :telemetry_configuration_state (Hash<String,String>)

    A key-value pair to filter resources based on the telemetry type and the state of the telemetry configuration. The key is the telemetry type and the value is the state.

  • :resource_tags (Hash<String,String>)

    A key-value pair to filter resources based on tags associated with the resource. For more information about tags, see [What are tags?]

    [1]: docs.aws.amazon.com/whitepapers/latest/tagging-best-practices/what-are-tags.html

  • :max_results (Integer)

    A number field used to limit the number of results within the returned list.

  • :next_token (String)

    The token for the next set of items to return. A previous call generates this token.

Returns:

See Also:



867
868
869
870
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 867

def list_resource_telemetry(params = {}, options = {})
  req = build_request(:list_resource_telemetry, params)
  req.send_request(options)
end

#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput

Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_resource_telemetry_for_organization({
  account_identifiers: ["AccountIdentifier"],
  resource_identifier_prefix: "ResourceIdentifierPrefix",
  resource_types: ["AWS::EC2::Instance"], # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
  telemetry_configuration_state: {
    "Logs" => "Enabled", # accepts Enabled, Disabled, NotApplicable
  },
  resource_tags: {
    "TagKey" => "TagValue",
  },
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.telemetry_configurations #=> Array
resp.telemetry_configurations[0]. #=> String
resp.telemetry_configurations[0].telemetry_configuration_state #=> Hash
resp.telemetry_configurations[0].telemetry_configuration_state["TelemetryType"] #=> String, one of "Enabled", "Disabled", "NotApplicable"
resp.telemetry_configurations[0].resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_configurations[0].resource_identifier #=> String
resp.telemetry_configurations[0].resource_tags #=> Hash
resp.telemetry_configurations[0].resource_tags["String"] #=> String
resp.telemetry_configurations[0].last_update_time_stamp #=> Integer
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :account_identifiers (Array<String>)

    A list of Amazon Web Services accounts used to filter the resources to those associated with the specified accounts.

  • :resource_identifier_prefix (String)

    A string used to filter resources in the organization which have a ‘ResourceIdentifier` starting with the `ResourceIdentifierPrefix`.

  • :resource_types (Array<String>)

    A list of resource types used to filter resources in the organization. If this parameter is provided, the resources will be returned in the same order used in the request.

  • :telemetry_configuration_state (Hash<String,String>)

    A key-value pair to filter resources in the organization based on the telemetry type and the state of the telemetry configuration. The key is the telemetry type and the value is the state.

  • :resource_tags (Hash<String,String>)

    A key-value pair to filter resources in the organization based on tags associated with the resource. Fore more information about tags, see

    What are tags?][1

    [1]: docs.aws.amazon.com/whitepapers/latest/tagging-best-practices/what-are-tags.html

  • :max_results (Integer)

    A number field used to limit the number of results within the returned list.

  • :next_token (String)

    The token for the next set of items to return. A previous call provides this token.

Returns:

See Also:



950
951
952
953
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 950

def list_resource_telemetry_for_organization(params = {}, options = {})
  req = build_request(:list_resource_telemetry_for_organization, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput

Lists all tags attached to the specified telemetry rule resource.

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "ResourceArn", # required
})

Response structure


resp.tags #=> Hash
resp.tags["String"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the telemetry rule resource whose tags you want to list.

Returns:

See Also:



980
981
982
983
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 980

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput

Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_telemetry_rules({
  rule_name_prefix: "String",
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.telemetry_rule_summaries #=> Array
resp.telemetry_rule_summaries[0].rule_name #=> String
resp.telemetry_rule_summaries[0].rule_arn #=> String
resp.telemetry_rule_summaries[0].created_time_stamp #=> Integer
resp.telemetry_rule_summaries[0].last_update_time_stamp #=> Integer
resp.telemetry_rule_summaries[0].resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_rule_summaries[0].telemetry_type #=> String, one of "Logs", "Metrics", "Traces"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_name_prefix (String)

    A string to filter telemetry rules whose names begin with the specified prefix.

  • :max_results (Integer)

    The maximum number of telemetry rules to return in a single call.

  • :next_token (String)

    The token for the next set of results. A previous call generates this token.

Returns:

See Also:



1029
1030
1031
1032
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1029

def list_telemetry_rules(params = {}, options = {})
  req = build_request(:list_telemetry_rules, params)
  req.send_request(options)
end

#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput

Lists all telemetry rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_telemetry_rules_for_organization({
  rule_name_prefix: "String",
  source_account_ids: ["AccountIdentifier"],
  source_organization_unit_ids: ["OrganizationUnitIdentifier"],
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.telemetry_rule_summaries #=> Array
resp.telemetry_rule_summaries[0].rule_name #=> String
resp.telemetry_rule_summaries[0].rule_arn #=> String
resp.telemetry_rule_summaries[0].created_time_stamp #=> Integer
resp.telemetry_rule_summaries[0].last_update_time_stamp #=> Integer
resp.telemetry_rule_summaries[0].resource_type #=> String, one of "AWS::EC2::Instance", "AWS::EC2::VPC", "AWS::Lambda::Function"
resp.telemetry_rule_summaries[0].telemetry_type #=> String, one of "Logs", "Metrics", "Traces"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_name_prefix (String)

    A string to filter organization telemetry rules whose names begin with the specified prefix.

  • :source_account_ids (Array<String>)

    The list of account IDs to filter organization telemetry rules by their source accounts.

  • :source_organization_unit_ids (Array<String>)

    The list of organizational unit IDs to filter organization telemetry rules by their source organizational units.

  • :max_results (Integer)

    The maximum number of organization telemetry rules to return in a single call.

  • :next_token (String)

    The token for the next set of results. A previous call generates this token.

Returns:

See Also:



1090
1091
1092
1093
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1090

def list_telemetry_rules_for_organization(params = {}, options = {})
  req = build_request(:list_telemetry_rules_for_organization, params)
  req.send_request(options)
end

#start_telemetry_evaluation(params = {}) ⇒ Struct

This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1104
1105
1106
1107
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1104

def start_telemetry_evaluation(params = {}, options = {})
  req = build_request(:start_telemetry_evaluation, params)
  req.send_request(options)
end

#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct

This actions begins onboarding the organization and all member accounts to the telemetry config feature.

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1118
1119
1120
1121
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1118

def start_telemetry_evaluation_for_organization(params = {}, options = {})
  req = build_request(:start_telemetry_evaluation_for_organization, params)
  req.send_request(options)
end

#stop_telemetry_evaluation(params = {}) ⇒ Struct

This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1132
1133
1134
1135
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1132

def stop_telemetry_evaluation(params = {}, options = {})
  req = build_request(:stop_telemetry_evaluation, params)
  req.send_request(options)
end

#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct

This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1146
1147
1148
1149
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1146

def stop_telemetry_evaluation_for_organization(params = {}, options = {})
  req = build_request(:stop_telemetry_evaluation_for_organization, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Adds or updates tags for a telemetry rule resource.

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "ResourceArn", # required
  tags: { # required
    "TagKey" => "TagValue",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the telemetry rule resource to tag.

  • :tags (required, Hash<String,String>)

    The key-value pairs to add or update for the telemetry rule resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1174
1175
1176
1177
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1174

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes tags from a telemetry rule resource.

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "ResourceArn", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The Amazon Resource Name (ARN) of the telemetry rule resource to remove tags from.

  • :tag_keys (required, Array<String>)

    The list of tag keys to remove from the telemetry rule resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1201
1202
1203
1204
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1201

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput

Updates an existing telemetry rule in your account.

Examples:

Request syntax with placeholder values


resp = client.update_telemetry_rule({
  rule_identifier: "RuleIdentifier", # required
  rule: { # required
    resource_type: "AWS::EC2::Instance", # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
    telemetry_type: "Logs", # required, accepts Logs, Metrics, Traces
    destination_configuration: {
      destination_type: "cloud-watch-logs", # accepts cloud-watch-logs
      destination_pattern: "String",
      retention_in_days: 1,
      vpc_flow_log_parameters: {
        log_format: "String",
        traffic_type: "String",
        max_aggregation_interval: 1,
      },
    },
    scope: "String",
    selection_criteria: "String",
  },
})

Response structure


resp.rule_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the telemetry rule to update.

  • :rule (required, Types::TelemetryRule)

    The new configuration details for the telemetry rule.

Returns:

See Also:



1248
1249
1250
1251
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1248

def update_telemetry_rule(params = {}, options = {})
  req = build_request(:update_telemetry_rule, params)
  req.send_request(options)
end

#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput

Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.

Examples:

Request syntax with placeholder values


resp = client.update_telemetry_rule_for_organization({
  rule_identifier: "RuleIdentifier", # required
  rule: { # required
    resource_type: "AWS::EC2::Instance", # accepts AWS::EC2::Instance, AWS::EC2::VPC, AWS::Lambda::Function
    telemetry_type: "Logs", # required, accepts Logs, Metrics, Traces
    destination_configuration: {
      destination_type: "cloud-watch-logs", # accepts cloud-watch-logs
      destination_pattern: "String",
      retention_in_days: 1,
      vpc_flow_log_parameters: {
        log_format: "String",
        traffic_type: "String",
        max_aggregation_interval: 1,
      },
    },
    scope: "String",
    selection_criteria: "String",
  },
})

Response structure


resp.rule_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :rule_identifier (required, String)

    The identifier (name or ARN) of the organization telemetry rule to update.

  • :rule (required, Types::TelemetryRule)

    The new configuration details for the organization telemetry rule, including resource type, telemetry type, and destination configuration.

Returns:

See Also:



1301
1302
1303
1304
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1301

def update_telemetry_rule_for_organization(params = {}, options = {})
  req = build_request(:update_telemetry_rule_for_organization, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1330
1331
1332
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1330

def waiter_names
  []
end