Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account.
-
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization.
-
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account.
-
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule.
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
-
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified telemetry rule resource.
-
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account.
-
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a telemetry rule resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a telemetry rule resource.
-
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
-
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1337 1338 1339 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1337 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1340 1341 1342 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1340 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1310 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#create_telemetry_rule(params = {}) ⇒ Types::CreateTelemetryRuleOutput
Creates a telemetry rule that defines how telemetry should be configured for Amazon Web Services resources in your account. The rule specifies which resources should have telemetry enabled and how that telemetry data should be collected based on resource type, telemetry type, and selection criteria.
537 538 539 540 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 537 def create_telemetry_rule(params = {}, = {}) req = build_request(:create_telemetry_rule, params) req.send_request() end |
#create_telemetry_rule_for_organization(params = {}) ⇒ Types::CreateTelemetryRuleForOrganizationOutput
Creates a telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
596 597 598 599 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 596 def create_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:create_telemetry_rule_for_organization, params) req.send_request() end |
#delete_telemetry_rule(params = {}) ⇒ Struct
Deletes a telemetry rule from your account. Any telemetry configurations previously created by the rule will remain but no new resources will be configured by this rule.
620 621 622 623 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 620 def delete_telemetry_rule(params = {}, = {}) req = build_request(:delete_telemetry_rule, params) req.send_request() end |
#delete_telemetry_rule_for_organization(params = {}) ⇒ Struct
Deletes an organization-wide telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
645 646 647 648 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 645 def delete_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:delete_telemetry_rule_for_organization, params) req.send_request() end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
668 669 670 671 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 668 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an Amazon Web Services Organization or an assigned Delegated Admin Account of Amazon CloudWatch telemetry config.
692 693 694 695 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 692 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#get_telemetry_rule(params = {}) ⇒ Types::GetTelemetryRuleOutput
Retrieves the details of a specific telemetry rule in your account.
737 738 739 740 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 737 def get_telemetry_rule(params = {}, = {}) req = build_request(:get_telemetry_rule, params) req.send_request() end |
#get_telemetry_rule_for_organization(params = {}) ⇒ Types::GetTelemetryRuleForOrganizationOutput
Retrieves the details of a specific organization telemetry rule. This operation can only be called by the organization’s management account or a delegated administrator account.
785 786 787 788 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 785 def get_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:get_telemetry_rule_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
867 868 869 870 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 867 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for Amazon Web Services resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
950 951 952 953 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 950 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags attached to the specified telemetry rule resource.
980 981 982 983 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 980 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_telemetry_rules(params = {}) ⇒ Types::ListTelemetryRulesOutput
Lists all telemetry rules in your account. You can filter the results by specifying a rule name prefix.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1029 1030 1031 1032 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1029 def list_telemetry_rules(params = {}, = {}) req = build_request(:list_telemetry_rules, params) req.send_request() end |
#list_telemetry_rules_for_organization(params = {}) ⇒ Types::ListTelemetryRulesForOrganizationOutput
Lists all telemetry rules in your organization. This operation can only be called by the organization’s management account or a delegated administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1090 def list_telemetry_rules_for_organization(params = {}, = {}) req = build_request(:list_telemetry_rules_for_organization, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding the caller Amazon Web Services account to the telemetry config feature.
1104 1105 1106 1107 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1104 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
1118 1119 1120 1121 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1118 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller Amazon Web Services account from the telemetry config feature.
1132 1133 1134 1135 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1132 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller Amazon Web Services account from the telemetry config feature.
1146 1147 1148 1149 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1146 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a telemetry rule resource.
1174 1175 1176 1177 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1174 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a telemetry rule resource.
1201 1202 1203 1204 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1201 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_telemetry_rule(params = {}) ⇒ Types::UpdateTelemetryRuleOutput
Updates an existing telemetry rule in your account.
1248 1249 1250 1251 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1248 def update_telemetry_rule(params = {}, = {}) req = build_request(:update_telemetry_rule, params) req.send_request() end |
#update_telemetry_rule_for_organization(params = {}) ⇒ Types::UpdateTelemetryRuleForOrganizationOutput
Updates an existing telemetry rule that applies across an Amazon Web Services Organization. This operation can only be called by the organization’s management account or a delegated administrator account.
1301 1302 1303 1304 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1301 def update_telemetry_rule_for_organization(params = {}, = {}) req = build_request(:update_telemetry_rule_for_organization, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1330 1331 1332 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 1330 def waiter_names [] end |