Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config in the organization.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding onboarding the caller AWS account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller AWS account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller AWS account from thef telemetry config feature.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
781 782 783 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 781 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
784 785 786 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 784 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 754 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
500 501 502 503 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 500 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an AWS Organization or an assigned Delegated Admin Account of AWS CloudWatch telemetry config.
524 525 526 527 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 524 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
606 607 608 609 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 606 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
689 690 691 692 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 689 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding onboarding the caller AWS account to the telemetry config feature.
703 704 705 706 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 703 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
717 718 719 720 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 717 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller AWS account from the telemetry config feature.
731 732 733 734 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 731 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller AWS account from thef telemetry config feature.
745 746 747 748 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 745 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
774 775 776 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 774 def waiter_names [] end |