Class: Aws::ObservabilityAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ObservabilityAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-observabilityadmin/client.rb
Overview
An API client for ObservabilityAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ObservabilityAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
-
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization.
-
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config.
-
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config in the organization.
-
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding onboarding the caller AWS account to the telemetry config feature.
-
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
-
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller AWS account from the telemetry config feature.
-
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller AWS account from thef telemetry config feature.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
466 467 468 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 466 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
771 772 773 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 771 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
774 775 776 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 774 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 744 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ObservabilityAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-observabilityadmin' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#get_telemetry_evaluation_status(params = {}) ⇒ Types::GetTelemetryEvaluationStatusOutput
Returns the current onboarding status of the telemetry config feature, including the status of the feature and reason the feature failed to start or stop.
490 491 492 493 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 490 def get_telemetry_evaluation_status(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status, params) req.send_request() end |
#get_telemetry_evaluation_status_for_organization(params = {}) ⇒ Types::GetTelemetryEvaluationStatusForOrganizationOutput
This returns the onboarding status of the telemetry configuration feature for the organization. It can only be called by a Management Account of an AWS Organization or an assigned Delegated Admin Account of AWS CloudWatch telemetry config.
514 515 516 517 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 514 def get_telemetry_evaluation_status_for_organization(params = {}, = {}) req = build_request(:get_telemetry_evaluation_status_for_organization, params) req.send_request() end |
#list_resource_telemetry(params = {}) ⇒ Types::ListResourceTelemetryOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config. For more information, see [Auditing CloudWatch telemetry configurations].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/telemetry-config-cloudwatch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
596 597 598 599 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 596 def list_resource_telemetry(params = {}, = {}) req = build_request(:list_resource_telemetry, params) req.send_request() end |
#list_resource_telemetry_for_organization(params = {}) ⇒ Types::ListResourceTelemetryForOrganizationOutput
Returns a list of telemetry configurations for AWS resources supported by telemetry config in the organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
679 680 681 682 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 679 def list_resource_telemetry_for_organization(params = {}, = {}) req = build_request(:list_resource_telemetry_for_organization, params) req.send_request() end |
#start_telemetry_evaluation(params = {}) ⇒ Struct
This action begins onboarding onboarding the caller AWS account to the telemetry config feature.
693 694 695 696 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 693 def start_telemetry_evaluation(params = {}, = {}) req = build_request(:start_telemetry_evaluation, params) req.send_request() end |
#start_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This actions begins onboarding the organization and all member accounts to the telemetry config feature.
707 708 709 710 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 707 def start_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:start_telemetry_evaluation_for_organization, params) req.send_request() end |
#stop_telemetry_evaluation(params = {}) ⇒ Struct
This action begins offboarding the caller AWS account from the telemetry config feature.
721 722 723 724 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 721 def stop_telemetry_evaluation(params = {}, = {}) req = build_request(:stop_telemetry_evaluation, params) req.send_request() end |
#stop_telemetry_evaluation_for_organization(params = {}) ⇒ Struct
This action offboards the Organization of the caller AWS account from thef telemetry config feature.
735 736 737 738 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 735 def stop_telemetry_evaluation_for_organization(params = {}, = {}) req = build_request(:stop_telemetry_evaluation_for_organization, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
764 765 766 |
# File 'lib/aws-sdk-observabilityadmin/client.rb', line 764 def waiter_names [] end |