Class: Aws::ObservabilityAdmin::Types::GetTelemetryRuleForOrganizationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_time_stampInteger

The timestamp when the organization telemetry rule was created.

Returns:

  • (Integer)


228
229
230
231
232
233
234
235
236
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 228

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_time_stampInteger

The timestamp when the organization telemetry rule was last updated.

Returns:

  • (Integer)


228
229
230
231
232
233
234
235
236
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 228

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule)
  SENSITIVE = []
  include Aws::Structure
end

#rule_arnString

The Amazon Resource Name (ARN) of the organization telemetry rule.

Returns:

  • (String)


228
229
230
231
232
233
234
235
236
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 228

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule)
  SENSITIVE = []
  include Aws::Structure
end

#rule_nameString

The name of the organization telemetry rule.

Returns:

  • (String)


228
229
230
231
232
233
234
235
236
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 228

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule)
  SENSITIVE = []
  include Aws::Structure
end

#telemetry_ruleTypes::TelemetryRule

The configuration details of the organization telemetry rule.



228
229
230
231
232
233
234
235
236
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 228

class GetTelemetryRuleForOrganizationOutput < Struct.new(
  :rule_name,
  :rule_arn,
  :created_time_stamp,
  :last_update_time_stamp,
  :telemetry_rule)
  SENSITIVE = []
  include Aws::Structure
end