Class: Aws::ObservabilityAdmin::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

The requested operation would exceed the allowed quota for the specified resource type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amzn_error_typeString

The name of the exception.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

The code for the exceeded service quota.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource which exceeds the service quota.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource which exceeds the service quota.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

The code for the service of the exceeded quota.

Returns:

  • (String)


1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 1972

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code,
  :amzn_error_type)
  SENSITIVE = []
  include Aws::Structure
end