Class: Aws::ObservabilityAdmin::Types::StartTelemetryEvaluationForOrganizationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::StartTelemetryEvaluationForOrganizationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_regions ⇒ Boolean
If set to ‘true`, telemetry evaluation for the organization starts in all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition.
-
#regions ⇒ Array<String>
An optional list of Amazon Web Services Regions to include in multi-region telemetry evaluation for the organization.
Instance Attribute Details
#all_regions ⇒ Boolean
If set to ‘true`, telemetry evaluation for the organization starts in all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition. The current region becomes the home region for managing multi-region evaluation for the organization. When new regions become available, evaluation automatically expands to include them. Mutually exclusive with `Regions`.
2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2034 class StartTelemetryEvaluationForOrganizationInput < Struct.new( :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
An optional list of Amazon Web Services Regions to include in multi-region telemetry evaluation for the organization. The current region is always implicitly included and must not be specified in this list. When provided, telemetry evaluation starts in the current region and propagates to all specified regions for the organization. Mutually exclusive with ‘AllRegions`. If neither `Regions` nor `AllRegions` is provided, the operation applies only to the current region.
2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2034 class StartTelemetryEvaluationForOrganizationInput < Struct.new( :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |