Class: Aws::ObservabilityAdmin::Types::TelemetryDestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::TelemetryDestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Configuration specifying where and how telemetry data should be delivered for Amazon Web Services resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloudtrail_parameters ⇒ Types::CloudtrailParameters
Configuration parameters specific to Amazon Web Services CloudTrail when CloudTrail is the source type.
-
#destination_pattern ⇒ String
The pattern used to generate the destination path or name, supporting macros like <resourceId> and <accountId>.
-
#destination_type ⇒ String
The type of destination for the telemetry data (e.g., "Amazon CloudWatch Logs", "S3").
-
#elb_load_balancer_logging_parameters ⇒ Types::ELBLoadBalancerLoggingParameters
Configuration parameters specific to ELB load balancer logging when ELB is the resource type.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed Amazon Web Services KMS key used to encrypt the log groups created during telemetry rule remediation.
-
#log_delivery_parameters ⇒ Types::LogDeliveryParameters
The configuration parameters for log delivery when the resource type supports configurable log types, such as Amazon Bedrock Knowledge Bases or Elastic Load Balancing Application Load Balancers.
-
#msk_monitoring_parameters ⇒ Types::MskMonitoringParameters
Configuration parameters specific to MSK monitoring when MSK is the resource type.
-
#retention_in_days ⇒ Integer
The number of days to retain the telemetry data in the destination.
-
#vpc_flow_log_parameters ⇒ Types::VPCFlowLogParameters
Configuration parameters specific to VPC Flow Logs when VPC is the resource type.
-
#waf_logging_parameters ⇒ Types::WAFLoggingParameters
Configuration parameters specific to WAF logging when WAF is the resource type.
Instance Attribute Details
#cloudtrail_parameters ⇒ Types::CloudtrailParameters
Configuration parameters specific to Amazon Web Services CloudTrail when CloudTrail is the source type.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#destination_pattern ⇒ String
The pattern used to generate the destination path or name, supporting macros like <resourceId> and <accountId>.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#destination_type ⇒ String
The type of destination for the telemetry data (e.g., "Amazon CloudWatch Logs", "S3").
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#elb_load_balancer_logging_parameters ⇒ Types::ELBLoadBalancerLoggingParameters
Configuration parameters specific to ELB load balancer logging when ELB is the resource type.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed Amazon Web Services KMS key used to encrypt the log groups created during telemetry rule remediation.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#log_delivery_parameters ⇒ Types::LogDeliveryParameters
The configuration parameters for log delivery when the resource type supports configurable log types, such as Amazon Bedrock Knowledge Bases or Elastic Load Balancing Application Load Balancers.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#msk_monitoring_parameters ⇒ Types::MskMonitoringParameters
Configuration parameters specific to MSK monitoring when MSK is the resource type.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days to retain the telemetry data in the destination.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_flow_log_parameters ⇒ Types::VPCFlowLogParameters
Configuration parameters specific to VPC Flow Logs when VPC is the resource type.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#waf_logging_parameters ⇒ Types::WAFLoggingParameters
Configuration parameters specific to WAF logging when WAF is the resource type.
2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2307 class TelemetryDestinationConfiguration < Struct.new( :destination_type, :destination_pattern, :retention_in_days, :vpc_flow_log_parameters, :cloudtrail_parameters, :elb_load_balancer_logging_parameters, :waf_logging_parameters, :log_delivery_parameters, :msk_monitoring_parameters, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |