Class: Aws::ObservabilityAdmin::Types::TelemetryRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::ObservabilityAdmin::Types::TelemetryRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-observabilityadmin/types.rb
Overview
Defines how telemetry should be configured for specific Amazon Web Services resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_regions ⇒ Boolean
If set to
true, the telemetry rule is replicated to all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition. -
#allow_field_updates ⇒ Boolean
If set to
true, Amazon CloudWatch Observability Admin detects and remediates configuration drift in telemetry resources that it manages. -
#destination_configuration ⇒ Types::TelemetryDestinationConfiguration
Configuration specifying where and how the telemetry data should be delivered.
-
#regions ⇒ Array<String>
An optional list of Amazon Web Services Regions where this telemetry rule should be replicated.
-
#resource_type ⇒ String
The type of Amazon Web Services resource to configure telemetry for (for example,
AWS::EC2::VPC,AWS::EKS::Cluster,AWS::ElasticLoadBalancingV2::LoadBalancer, orAWS::Bedrock::KnowledgeBase). -
#scope ⇒ String
The organizational scope to which the rule applies, specified using accounts or organizational units.
-
#selection_criteria ⇒ String
Criteria for selecting which resources the rule applies to, such as resource tags.
-
#telemetry_source_types ⇒ Array<String>
The specific telemetry source types to configure for the resource, such as VPC_FLOW_LOGS or EKS_AUDIT_LOGS.
-
#telemetry_type ⇒ String
The type of telemetry to collect (Logs, Metrics, or Traces).
Instance Attribute Details
#all_regions ⇒ Boolean
If set to true, the telemetry rule is replicated to all Amazon Web
Services Regions where Amazon CloudWatch Observability Admin is
available in the current partition. When new regions become
available, the rule automatically replicates to them. Mutually
exclusive with Regions.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#allow_field_updates ⇒ Boolean
If set to true, Amazon CloudWatch Observability Admin detects and
remediates configuration drift in telemetry resources that it
manages. For example, if a VPC flow log's format, traffic type, or
aggregation interval no longer matches the rule's destination
configuration, the flow log is replaced with one that matches. Only
Observability Admin-managed resources are updated; customer-created
resources are never modified. Currently supported for
AWS::EC2::VPC resources (VPC flow logs).
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#destination_configuration ⇒ Types::TelemetryDestinationConfiguration
Configuration specifying where and how the telemetry data should be delivered.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
An optional list of Amazon Web Services Regions where this telemetry
rule should be replicated. When specified, the rule is created in
the home region and automatically replicated to all listed regions.
Mutually exclusive with AllRegions.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of Amazon Web Services resource to configure telemetry for
(for example, AWS::EC2::VPC, AWS::EKS::Cluster,
AWS::ElasticLoadBalancingV2::LoadBalancer, or
AWS::Bedrock::KnowledgeBase).
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
The organizational scope to which the rule applies, specified using accounts or organizational units.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#selection_criteria ⇒ String
Criteria for selecting which resources the rule applies to, such as resource tags.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#telemetry_source_types ⇒ Array<String>
The specific telemetry source types to configure for the resource, such as VPC_FLOW_LOGS or EKS_AUDIT_LOGS. TelemetrySourceTypes must be correlated with the specific resource type.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |
#telemetry_type ⇒ String
The type of telemetry to collect (Logs, Metrics, or Traces).
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 |
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2545 class TelemetryRule < Struct.new( :resource_type, :telemetry_type, :telemetry_source_types, :destination_configuration, :scope, :selection_criteria, :allow_field_updates, :regions, :all_regions) SENSITIVE = [] include Aws::Structure end |