Class: Aws::ObservabilityAdmin::Types::TelemetryRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-observabilityadmin/types.rb

Overview

Defines how telemetry should be configured for specific Amazon Web Services resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_regionsBoolean

If set to ‘true`, the telemetry rule is replicated to all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition. When new regions become available, the rule automatically replicates to them. Mutually exclusive with `Regions`.

Returns:

  • (Boolean)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#allow_field_updatesBoolean

If set to ‘true`, Amazon CloudWatch Observability Admin detects and remediates configuration drift in telemetry resources that it manages. For example, if a VPC flow log’s format, traffic type, or aggregation interval no longer matches the rule’s destination configuration, the flow log is replaced with one that matches. Only Observability Admin-managed resources are updated; customer-created resources are never modified. Currently supported for ‘AWS::EC2::VPC` resources (VPC flow logs).

Returns:

  • (Boolean)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configurationTypes::TelemetryDestinationConfiguration

Configuration specifying where and how the telemetry data should be delivered.



2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#regionsArray<String>

An optional list of Amazon Web Services Regions where this telemetry rule should be replicated. When specified, the rule is created in the home region and automatically replicated to all listed regions. Mutually exclusive with ‘AllRegions`.

Returns:

  • (Array<String>)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of Amazon Web Services resource to configure telemetry for (e.g., “AWS::EC2::VPC”, “AWS::EKS::Cluster”, “AWS::WAFv2::WebACL”).

Returns:

  • (String)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

The organizational scope to which the rule applies, specified using accounts or organizational units.

Returns:

  • (String)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#selection_criteriaString

Criteria for selecting which resources the rule applies to, such as resource tags.

Returns:

  • (String)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#telemetry_source_typesArray<String>

The specific telemetry source types to configure for the resource, such as VPC_FLOW_LOGS or EKS_AUDIT_LOGS. TelemetrySourceTypes must be correlated with the specific resource type.

Returns:

  • (Array<String>)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end

#telemetry_typeString

The type of telemetry to collect (Logs, Metrics, or Traces).

Returns:

  • (String)


2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
# File 'lib/aws-sdk-observabilityadmin/types.rb', line 2433

class TelemetryRule < Struct.new(
  :resource_type,
  :telemetry_type,
  :telemetry_source_types,
  :destination_configuration,
  :scope,
  :selection_criteria,
  :allow_field_updates,
  :regions,
  :all_regions)
  SENSITIVE = []
  include Aws::Structure
end